

#ifndef SBK_KUNITCONVERSION_PYTHON_H
#define SBK_KUNITCONVERSION_PYTHON_H

//workaround to access protected functions
#define protected public

#include <sbkpython.h>
#include <sbkmodule.h>
#include <sbkconverter.h>
// Module Includes
#include <pyside6_qtcore_python.h>

// Bound library includes
#include <converter.h>
#include <unit.h>
#include <unitcategory.h>
#include <value.h>
// Conversion Includes - Primitive Types
#include <QAnyStringView>
#include <qbytearrayview.h>
#include <qchar.h>
#include <QtCore/qlatin1stringview.h>
#include <QString>
#include <QStringList>
#include <QStringView>

// Conversion Includes - Container Types
#include <QHash>
#include <QList>
#include <QMap>
#include <QMultiHash>
#include <QMultiMap>
#include <QPair>
#include <QQueue>
#include <QSet>
#include <QStack>
#include <array>
#include <list>
#include <map>
#include <utility>
#include <unordered_map>
#include <vector>


// Type indices
enum : int {
    SBK_KUnitConversion_CategoryId_IDX                       = 1,
    SBK_KUnitConversion_UnitId_IDX                           = 5,
    SBK_KUnitConversionKUnitConversion_IDX                   = 0,
    SBK_KUnitConversion_Converter_IDX                        = 2,
    SBK_KUnitConversion_Unit_IDX                             = 3,
    SBK_KUnitConversion_UnitCategory_IDX                     = 4,
    SBK_KUnitConversion_UpdateJob_IDX                        = 6,
    SBK_KUnitConversion_Value_IDX                            = 7,
    SBK_KUnitConversion_IDX_COUNT                            = 8,
};

// This variable stores all Python types exported by this module.
extern Shiboken::Module::TypeInitStruct *SbkKUnitConversionTypeStructs;

// This variable stores the Python module object exported by this module.
extern PyObject *SbkKUnitConversionModuleObject;

// This variable stores all type converters exported by this module.
extern SbkConverter **SbkKUnitConversionTypeConverters;

// Converter indices
enum [[deprecated]] : int {
    SBK_KUNITCONVERSION_QLIST_INT_IDX                        = 0, // QList<int>
    SBK_KUNITCONVERSION_QLIST_KUNITCONVERSION_UNIT_IDX       = 1, // QList<KUnitConversion::Unit>
    SBK_KUNITCONVERSION_QLIST_KUNITCONVERSION_UNITCATEGORY_IDX = 2, // QList<KUnitConversion::UnitCategory>
    SBK_KUNITCONVERSION_QLIST_QVARIANT_IDX                   = 3, // QList<QVariant>
    SBK_KUNITCONVERSION_QLIST_QSTRING_IDX                    = 4, // QList<QString>
    SBK_KUNITCONVERSION_QMAP_QSTRING_QVARIANT_IDX            = 5, // QMap<QString,QVariant>
    SBK_KUNITCONVERSION_CONVERTERS_IDX_COUNT                 = 6,
};

// Converter indices
enum : int {
    SBK_KUnitConversion_QList_int_IDX                        = 0, // QList<int>
    SBK_KUnitConversion_QList_KUnitConversion_Unit_IDX       = 1, // QList<KUnitConversion::Unit>
    SBK_KUnitConversion_QList_KUnitConversion_UnitCategory_IDX = 2, // QList<KUnitConversion::UnitCategory>
    SBK_KUnitConversion_QList_QVariant_IDX                   = 3, // QList<QVariant>
    SBK_KUnitConversion_QList_QString_IDX                    = 4, // QList<QString>
    SBK_KUnitConversion_QMap_QString_QVariant_IDX            = 5, // QMap<QString,QVariant>
    SBK_KUnitConversion_CONVERTERS_IDX_COUNT                 = 6,
};
// Macros for type check

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
namespace Shiboken
{

// PyType functions, to get the PyObjectType for a type T
template<> inline PyTypeObject *SbkType< ::KUnitConversion::CategoryId >() { return Shiboken::Module::get(SbkKUnitConversionTypeStructs[SBK_KUnitConversion_CategoryId_IDX]); }
template<> inline PyTypeObject *SbkType< ::KUnitConversion::UnitId >() { return Shiboken::Module::get(SbkKUnitConversionTypeStructs[SBK_KUnitConversion_UnitId_IDX]); }
template<> inline PyTypeObject *SbkType< ::KUnitConversion::Converter >() { return Shiboken::Module::get(SbkKUnitConversionTypeStructs[SBK_KUnitConversion_Converter_IDX]); }
template<> inline PyTypeObject *SbkType< ::KUnitConversion::Unit >() { return Shiboken::Module::get(SbkKUnitConversionTypeStructs[SBK_KUnitConversion_Unit_IDX]); }
template<> inline PyTypeObject *SbkType< ::KUnitConversion::UnitCategory >() { return Shiboken::Module::get(SbkKUnitConversionTypeStructs[SBK_KUnitConversion_UnitCategory_IDX]); }
template<> inline PyTypeObject *SbkType< ::KUnitConversion::UpdateJob >() { return Shiboken::Module::get(SbkKUnitConversionTypeStructs[SBK_KUnitConversion_UpdateJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::KUnitConversion::Value >() { return Shiboken::Module::get(SbkKUnitConversionTypeStructs[SBK_KUnitConversion_Value_IDX]); }

} // namespace Shiboken

QT_WARNING_POP
#endif // SBK_KUNITCONVERSION_PYTHON_H

