/*
 *   SPDX-FileCopyrightText: 2018 João Netto <joaonetto901@gmail.com>
 *
 *   SPDX-License-Identifier: LGPL-2.0-or-later
 */

#ifndef PERMEABILITY_P_H
#define PERMEABILITY_P_H

#include "unitcategory_p.h"

namespace KUnitConversion
{
namespace Permeability
{
    UnitCategory makeCategory();
};

} // KUnitConversion namespace

#endif
