/*
 *   SPDX-FileCopyrightText: 2010 Petri Damstén <damu@iki.fi>
 *   SPDX-FileCopyrightText: 2014 John Layt <jlayt@kde.org>
 *
 *   SPDX-License-Identifier: LGPL-2.0-or-later
 */

#ifndef ACCELERATION_P_H
#define ACCELERATION_P_H

#include "unitcategory_p.h"

namespace KUnitConversion
{
namespace Acceleration
{
    UnitCategory makeCategory();
};

} // KUnitConversion namespace

#endif
